@@ -1,4 +1,4 @@
-/* $Id: pending.c,v 1.89 2009/09/07 12:56:54 manu Exp $ */
+/* $Id: pending.c,v 1.92 2010/04/12 12:04:41 manu Exp $ */
 
 /*
  * Copyright (c) 2004 Emmanuel Dreyfus
@@ -34,7 +34,7 @@
 #ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #ifdef __RCSID  
-__RCSID("$Id: pending.c,v 1.89 2009/09/07 12:56:54 manu Exp $");
+__RCSID("$Id: pending.c,v 1.92 2010/04/12 12:04:41 manu Exp $");
 #endif
 #endif
 
@@ -73,6 +73,22 @@ __RCSID("$Id: pending.c,v 1.89 2009/09/07 12:56:54 manu Exp $");
 #include <dmalloc.h> 
 #endif
 
+tuple_t pending_check(struct sockaddr *, socklen_t, char *, char *, 
+    time_t *, time_t *, char *, time_t, time_t);
+time_t pending_tarpitted(struct sockaddr *, socklen_t, char *, char *);
+void pending_update(struct sockaddr *, socklen_t, char *, char *, 
+    time_t, tuple_update_type_t);
+void pending_rem(struct pending *);
+void pending_put(struct pending *, time_t);
+struct pending *pending_get(struct sockaddr *, socklen_t, char *, char *,
+    time_t, time_t, tuple_t);
+void pending_del(struct sockaddr *, socklen_t, char *, char *, time_t, 
+    time_t);
+void pending_del_addr(struct sockaddr *, socklen_t, char *, int);
+struct pending *pending_ref(struct pending *);
+void pending_free(struct pending *);
+tuple_cnt_t pending_textdump(FILE *);
+
 struct pending_bucket *pending_buckets;
 struct pendinglist pending_head;
 /* protects pending_head and pending_buckets */
@@ -138,12 +154,13 @@ pending_timeout(pending, now)
 
 /* pending_lock must be locked */
 struct pending *
-pending_get(sa, salen, from, rcpt, date, tupletype)  
+pending_get(sa, salen, from, rcpt, date, tarpit, tupletype)
 	struct sockaddr *sa;
 	socklen_t salen;
 	char *from;
 	char *rcpt;
 	time_t date;
+	time_t tarpit;
 	tuple_t tupletype;
 {
 	struct pending *pending;
@@ -156,7 +173,7 @@ pending_get(sa, salen, from, rcpt, date, tupletype)
 
 	bzero((void *)pending, sizeof(pending));
 	pending->p_tv.tv_sec = date;
-	pending->p_tarpit.tv_sec = 0;
+	pending->p_tarpit.tv_sec = tarpit;
 	pending->p_type = tupletype;
 
 	if ((pending->p_sa = malloc(salen)) == NULL) {
@@ -446,7 +463,7 @@ pending_check(sa, salen, from, rcpt, remaining, elapsed, queueid, delay, aw)
 	*/
 	accepted = now + delay;
 	rest = 0;
-	pending = pending_get(sa, salen, from, rcpt, accepted, T_PENDING);
+	pending = pending_get(sa, salen, from, rcpt, accepted, 0, T_PENDING);
 	if (pending) {
 		++dirty;
 		peer_create(pending);
