@@ -1,7 +1,7 @@
-/* $Id: spamd.c,v 1.11 2009/05/13 02:50:58 manu Exp $ */
+/* $Id: spamd.c,v 1.16 2010/07/12 01:38:14 manu Exp $ */
 
 /*
- * Copyright (c) 2008 Manuel Badzong, Emmanuel Dreyfus
+ * Copyright (c) 2008-2010 Manuel Badzong, Emmanuel Dreyfus
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@
 #ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #ifdef __RCSID
-__RCSID("$Id: spamd.c,v 1.11 2009/05/13 02:50:58 manu Exp $");
+__RCSID("$Id: spamd.c,v 1.16 2010/07/12 01:38:14 manu Exp $");
 #endif
 #endif
 
@@ -168,8 +168,11 @@ spamd_check(ad, stage, ap, priv)
 	spamd_rcvhdr(priv, rcvhdr, SPAMD_BUFLEN);
 
 	snprintf(buffer, SPAMD_BUFLEN,
-	  "CHECK SPAMC/1.2\r\nContent-length: %d\r\n\r\n",
-	  (unsigned int)(priv->priv_msgcount + strlen(rcvhdr)));
+	  "CHECK SPAMC/1.2\r\n"
+	  "Content-length: %d\r\n"
+	  "User: %s\r\n\r\n",
+	  (unsigned int)(priv->priv_msgcount + strlen(rcvhdr)),
+	   priv->priv_queueid);
 
 	if ((sock = spamd_socket(conf.c_spamdsocktype, 
 				 conf.c_spamdsock)) == -1)
@@ -186,11 +189,11 @@ spamd_check(ad, stage, ap, priv)
 			return -1;
 
 	TAILQ_FOREACH(h, &priv->priv_header, h_list)
-		if (spamd_write(sock, h->h_line, strlen(h->h_line)) == -1)
+		if (spamd_write(sock, h->h_line, h->h_len) == -1)
 			return -1;
 			
 	TAILQ_FOREACH(b, &priv->priv_body, b_list)
-		if (spamd_write(sock, b->b_lines, strlen(b->b_lines)) == -1)
+		if (spamd_write(sock, b->b_lines, b->b_len) == -1)
 			return -1;
 
 	if (spamd_read(sock, buffer, SPAMD_BUFLEN) == -1)
@@ -446,6 +449,8 @@ spamd_unix_socket(path)
 		return -1;
 	}
 
+	SET_CLOEXEC(sock);
+
 	if (connect(sock, (struct sockaddr*) &sun, sizeof(sun))) {
 		mg_log(LOG_ERR, "spamd connect failed: %s", strerror(errno));
 		return -1;
@@ -484,6 +489,8 @@ spamd_inet_socket(host, port)
 		if (sock == -1)
 			continue;
 
+		SET_CLOEXEC(sock);
+
 		if (connect(sock, res->ai_addr, res->ai_addrlen) == 0)
 			break;
 
